@@ -304,7 +304,10 @@ def interpret(branch, awkwardlib=None, swapbytes=True, cntvers=False, tobject=Tr
                     return asstring(skipbytes=1)
 
                 if isinstance(branch._streamer, uproot.rootio.TStreamerSTLstring):
-                    return asstring(skipbytes=7)
+                    if branch._isTClonesArray:
+                        return asgenobj(STLVector(STLString()), branch._context, 6)
+                    else:
+                        return asstring(skipbytes=7)
 
                 if getattr(branch._streamer, "_fType", None) == uproot.const.kCharStar:
                     return asstring(skipbytes=4)
@@ -317,7 +320,7 @@ def interpret(branch, awkwardlib=None, swapbytes=True, cntvers=False, tobject=Tr
                         else:
                             ascontent = asdtype(fromdtype, fromdtype)
                         if branch._isTClonesArray:
-                            return asgenobj(SimpleArray(STLVector(asdtype(">i2"))), branch._context, 6)
+                            return asgenobj(SimpleArray(STLVector(asdtype(fromdtype, fromdtype))), branch._context, 6)
                         else:
                             return asjagged(ascontent, skipbytes=10)
 
@@ -329,6 +332,8 @@ def interpret(branch, awkwardlib=None, swapbytes=True, cntvers=False, tobject=Tr
                                 obj = uproot.rootio._safename(branch._vecstreamer._fName)
                                 if obj in branch._context.classes:
                                     streamerClass = branch._context.classes.get(obj)
+                            if getattr(streamerClass, "_hasreadobjany", False):
+                                return None
 
                             if streamerClass.__name__ == "string":
                                 return asgenobj(STLVector(STLString(awkward)), branch._context, 6)
@@ -511,8 +516,38 @@ def interpret(branch, awkwardlib=None, swapbytes=True, cntvers=False, tobject=Tr
                 if branch.name.endswith(b".first") and branch._fClassName.startswith(b"pair<string,"):
                     return asgenobj(SimpleArray(STLString(awkward)), branch._context, 6)
 
+                if branch.name.endswith(b".second"):
+                    m = interpret._pairsecond.match(branch._fClassName)
+                    if m is not None:
+                        t, = m.groups()
+                        if t == b"vector<bool>" or t == b"vector<Bool_t>":
+                            return asgenobj(SimpleArray(STLVector(asdtype(awkward.numpy.bool_))), branch._context, 6)
+                        elif t == b"vector<char>" or t == b"vector<Char_t>":
+                            return asgenobj(SimpleArray(STLVector(asdtype("i1"))), branch._context, 6)
+                        elif t == b"vector<unsigned char>" or t == b"vector<UChar_t>" or t == b"vector<Byte_t>":
+                            return asgenobj(SimpleArray(STLVector(asdtype("u1"))), branch._context, 6)
+                        elif t == b"vector<short>" or t == b"vector<Short_t>":
+                            return asgenobj(SimpleArray(STLVector(asdtype("i2"))), branch._context, 6)
+                        elif t == b"vector<unsigned short>" or t == b"vector<UShort_t>":
+                            return asgenobj(SimpleArray(STLVector(asdtype("u2"))), branch._context, 6)
+                        elif t == b"vector<int>" or t == b"vector<Int_t>":
+                            return asgenobj(SimpleArray(STLVector(asdtype("i4"))), branch._context, 6)
+                        elif t == b"vector<unsigned int>" or t == b"vector<UInt_t>":
+                            return asgenobj(SimpleArray(STLVector(asdtype("u4"))), branch._context, 6)
+                        elif t == b"vector<long>" or t == b"vector<Long_t>":
+                            return asgenobj(SimpleArray(STLVector(asdtype("i8"))), branch._context, 6)
+                        elif t == b"vector<unsigned long>" or t == b"vector<ULong64_t>":
+                            return asgenobj(SimpleArray(STLVector(asdtype("u8"))), branch._context, 6)
+                        elif t == b"vector<float>" or t == b"vector<Float_t>":
+                            return asgenobj(SimpleArray(STLVector(asdtype("f4"))), branch._context, 6)
+                        elif t == b"vector<double>" or t == b"vector<Double_t>":
+                            return asgenobj(SimpleArray(STLVector(asdtype("f8"))), branch._context, 6)
+                        elif t == b"vector<string>":
+                            return asgenobj(SimpleArray(STLVector(STLString(awkward))), branch._context, 6)
+
         return None
 
 interpret._titlehasdims = re.compile(br"^([^\[\]]+)(\[[^\[\]]+\])+")
 interpret._itemdimpattern = re.compile(br"\[([1-9][0-9]*)\]")
 interpret._itemanypattern = re.compile(br"\[(.*)\]")
+interpret._pairsecond = re.compile(br"pair\<[^<>]*,(.*) \>")
